@@ -27,19 +27,20 @@ from __future__ import print_function, unicode_literals
 from collections import defaultdict
 from copy import copy
 import glob
-import gzip
+import locale
 import os
 import sys
 try:
     from urlparse import urlparse, urlsplit, urljoin
 except ImportError:
     from urllib.parse import urlparse, urlsplit, urljoin  # NOQA
+import warnings
 
 import lxml.html
 from yapsy.PluginManager import PluginManager
 import pytz
 
-if os.getenv('DEBUG'):
+if os.getenv('NIKOLA_DEBUG'):
     import logging
     logging.basicConfig(level=logging.DEBUG)
 else:
@@ -53,6 +54,7 @@ from .plugin_categories import (
     LateTask,
     PageCompiler,
     Task,
+    TaskMultiplier,
     TemplateSystem,
 )
 
@@ -67,13 +69,21 @@ class Nikola(object):
 
     Takes a site config as argument on creation.
     """
+    EXTRA_PLUGINS = [
+        'planetoid',
+        'ipynb',
+        'local_search',
+        'render_mustache',
+    ]
 
     def __init__(self, **config):
         """Setup proper environment for running tasks."""
 
         self.global_data = {}
         self.posts_per_year = defaultdict(list)
+        self.posts_per_month = defaultdict(list)
         self.posts_per_tag = defaultdict(list)
+        self.post_per_file = {}
         self.timeline = []
         self.pages = []
         self._scanned = False
@@ -83,21 +93,24 @@ class Nikola(object):
             self.configured = True
 
         # This is the default config
-        # TODO: fill it
         self.config = {
             'ADD_THIS_BUTTONS': True,
             'ANALYTICS': '',
             'ARCHIVE_PATH': "",
             'ARCHIVE_FILENAME': "archive.html",
             'CACHE_FOLDER': 'cache',
+            'CODE_COLOR_SCHEME': 'default',
             'COMMENTS_IN_GALLERIES': False,
             'COMMENTS_IN_STORIES': False,
             'CONTENT_FOOTER': '',
+            'CREATE_MONTHLY_ARCHIVE': False,
             'DATE_FORMAT': '%Y-%m-%d %H:%M',
             'DEFAULT_LANG': "en",
             'DEPLOY_COMMANDS': [],
             'DISABLED_PLUGINS': (),
             'DISQUS_FORUM': 'nikolademo',
+            'ENABLED_EXTRAS': (),
+            'EXTRA_HEAD_DATA': '',
             'FAVICONS': {},
             'FILE_METADATA_REGEXP': None,
             'FILES_FOLDERS': {'files': ''},
@@ -105,15 +118,21 @@ class Nikola(object):
             'GALLERY_PATH': 'galleries',
             'GZIP_FILES': False,
             'GZIP_EXTENSIONS': ('.txt', '.htm', '.html', '.css', '.js', '.json'),
+            'HIDE_SOURCELINK': False,
+            'HIDE_UNTRANSLATED_POSTS': False,
             'INDEX_DISPLAY_POST_COUNT': 10,
+            'INDEX_FILE': 'index.html',
             'INDEX_TEASERS': False,
             'INDEXES_TITLE': "",
             'INDEXES_PAGES': "",
             'INDEX_PATH': '',
             'LICENSE': '',
+            'LINK_CHECK_WHITELIST': [],
             'LISTINGS_FOLDER': 'listings',
+            'MARKDOWN_EXTENSIONS': ['fenced_code', 'codehilite'],
             'MAX_IMAGE_SIZE': 1280,
             'MATHJAX_CONFIG': '',
+            'OLD_THEME_SUPPORT': True,
             'OUTPUT_FOLDER': 'output',
             'post_compilers': {
                 "rest": ('.txt', '.rst'),
@@ -129,6 +148,7 @@ class Nikola(object):
                 ("posts/*.txt", "posts", "post.tmpl", True),
                 ("stories/*.txt", "stories", "story.tmpl", False),
             ),
+            'PRETTY_URLS': False,
             'REDIRECTIONS': [],
             'RSS_LINK': None,
             'RSS_PATH': '',
@@ -136,6 +156,8 @@ class Nikola(object):
             'SEARCH_FORM': '',
             'SLUG_TAG_PATH': True,
             'STORY_INDEX': False,
+            'STRIP_INDEXES': False,
+            'SITEMAP_INCLUDE_FILELESS_DIRS': True,
             'TAG_PATH': 'categories',
             'TAG_PAGES_ARE_INDEXES': False,
             'THEME': 'site',
@@ -149,6 +171,17 @@ class Nikola(object):
         }
 
         self.config.update(config)
+
+        # STRIP_INDEX_HTML config has been replaces with STRIP_INDEXES
+        # Port it if only the oldef form is there
+        if 'STRIP_INDEX_HTML' in config and 'STRIP_INDEXES' not in config:
+            print("WARNING: You should configure STRIP_INDEXES instead of STRIP_INDEX_HTML")
+            self.config['STRIP_INDEXES'] = config['STRIP_INDEX_HTML']
+
+        # PRETTY_URLS defaults to enabling STRIP_INDEXES unless explicitly disabled
+        if config.get('PRETTY_URLS', False) and 'STRIP_INDEXES' not in config:
+            self.config['STRIP_INDEXES'] = True
+
         self.config['TRANSLATIONS'] = self.config.get('TRANSLATIONS',
                                                       {self.config['DEFAULT_'
                                                       'LANG']: ''})
@@ -156,16 +189,19 @@ class Nikola(object):
         self.THEMES = utils.get_theme_chain(self.config['THEME'])
 
         self.MESSAGES = utils.load_messages(self.THEMES,
-                                            self.config['TRANSLATIONS'])
+                                            self.config['TRANSLATIONS'],
+                                            self.config['DEFAULT_LANG'])
 
         # SITE_URL is required, but if the deprecated BLOG_URL
         # is available, use it and warn
         if 'SITE_URL' not in self.config:
             if 'BLOG_URL' in self.config:
                 print("WARNING: You should configure SITE_URL instead of BLOG_URL")
-                print("See docs at FIXME put URL")
                 self.config['SITE_URL'] = self.config['BLOG_URL']
 
+        self.default_lang = self.config['DEFAULT_LANG']
+        self.translations = self.config['TRANSLATIONS']
+
         # BASE_URL defaults to SITE_URL
         if 'BASE_URL' not in self.config:
             self.config['BASE_URL'] = self.config.get('SITE_URL')
@@ -176,34 +212,62 @@ class Nikola(object):
             "LateTask": LateTask,
             "TemplateSystem": TemplateSystem,
             "PageCompiler": PageCompiler,
+            "TaskMultiplier": TaskMultiplier,
         })
         self.plugin_manager.setPluginInfoExtension('plugin')
-        self.plugin_manager.setPluginPlaces([
-            str(os.path.join(os.path.dirname(__file__), 'plugins')),
-            str(os.path.join(os.getcwd(), 'plugins')),
-        ])
-
+        if sys.version_info[0] == 3:
+            places = [
+                os.path.join(os.path.dirname(__file__), 'plugins'),
+                os.path.join(os.getcwd(), 'plugins'),
+            ]
+        else:
+            places = [
+                os.path.join(os.path.dirname(__file__), utils.sys_encode('plugins')),
+                os.path.join(os.getcwd(), utils.sys_encode('plugins')),
+            ]
+        self.plugin_manager.setPluginPlaces(places)
         self.plugin_manager.collectPlugins()
 
         self.commands = {}
         # Activate all command plugins
-        for pluginInfo in self.plugin_manager.getPluginsOfCategory("Command"):
-            if pluginInfo.name in self.config['DISABLED_PLUGINS']:
-                self.plugin_manager.removePluginFromCategory(pluginInfo, "Command")
+        for plugin_info in self.plugin_manager.getPluginsOfCategory("Command"):
+            if (plugin_info.name in self.config['DISABLED_PLUGINS']
+                or (plugin_info.name in self.EXTRA_PLUGINS and
+                    plugin_info.name not in self.config['ENABLED_EXTRAS'])):
+                self.plugin_manager.removePluginFromCategory(plugin_info, "Command")
                 continue
-            self.plugin_manager.activatePluginByName(pluginInfo.name)
-            pluginInfo.plugin_object.set_site(self)
-            pluginInfo.plugin_object.short_help = pluginInfo.description
-            self.commands[pluginInfo.name] = pluginInfo.plugin_object
+
+            self.plugin_manager.activatePluginByName(plugin_info.name)
+            plugin_info.plugin_object.set_site(self)
+            plugin_info.plugin_object.short_help = plugin_info.description
+            self.commands[plugin_info.name] = plugin_info.plugin_object
 
         # Activate all task plugins
         for task_type in ["Task", "LateTask"]:
-            for pluginInfo in self.plugin_manager.getPluginsOfCategory(task_type):
-                if pluginInfo.name in self.config['DISABLED_PLUGINS']:
-                    self.plugin_manager.removePluginFromCategory(pluginInfo, task_type)
+            for plugin_info in self.plugin_manager.getPluginsOfCategory(task_type):
+                if (plugin_info.name in self.config['DISABLED_PLUGINS']
+                    or (plugin_info.name in self.EXTRA_PLUGINS and
+                        plugin_info.name not in self.config['ENABLED_EXTRAS'])):
+                    self.plugin_manager.removePluginFromCategory(plugin_info, task_type)
                     continue
-                self.plugin_manager.activatePluginByName(pluginInfo.name)
-                pluginInfo.plugin_object.set_site(self)
+                self.plugin_manager.activatePluginByName(plugin_info.name)
+                plugin_info.plugin_object.set_site(self)
+
+        # Activate all multiplier plugins
+        for plugin_info in self.plugin_manager.getPluginsOfCategory("TaskMultiplier"):
+            if (plugin_info.name in self.config['DISABLED_PLUGINS']
+                or (plugin_info.name in self.EXTRA_PLUGINS and
+                    plugin_info.name not in self.config['ENABLED_EXTRAS'])):
+                self.plugin_manager.removePluginFromCategory(plugin_info, task_type)
+                continue
+            self.plugin_manager.activatePluginByName(plugin_info.name)
+            plugin_info.plugin_object.set_site(self)
+
+        # Activate all required compiler plugins
+        for plugin_info in self.plugin_manager.getPluginsOfCategory("PageCompiler"):
+            if plugin_info.name in self.config["post_compilers"].keys():
+                self.plugin_manager.activatePluginByName(plugin_info.name)
+                plugin_info.plugin_object.set_site(self)
 
         # set global_context for template rendering
         self.GLOBAL_CONTEXT = {
@@ -211,6 +275,7 @@ class Nikola(object):
 
         self.GLOBAL_CONTEXT['messages'] = self.MESSAGES
         self.GLOBAL_CONTEXT['_link'] = self.link
+        self.GLOBAL_CONTEXT['set_locale'] = s_l
         self.GLOBAL_CONTEXT['rel_link'] = self.rel_link
         self.GLOBAL_CONTEXT['abs_link'] = self.abs_link
         self.GLOBAL_CONTEXT['exists'] = self.file_exists
@@ -244,18 +309,27 @@ class Nikola(object):
             'CONTENT_FOOTER')
         self.GLOBAL_CONTEXT['rss_path'] = self.config.get('RSS_PATH')
         self.GLOBAL_CONTEXT['rss_link'] = self.config.get('RSS_LINK')
-        self.GLOBAL_CONTEXT['sidebar_links'] = self.config.get('SIDEBAR_LINKS')
+
+        self.GLOBAL_CONTEXT['sidebar_links'] = utils.Functionary(list, self.config['DEFAULT_LANG'])
+        for k, v in self.config.get('SIDEBAR_LINKS', {}).items():
+            self.GLOBAL_CONTEXT['sidebar_links'][k] = v
+
         self.GLOBAL_CONTEXT['twitter_card'] = self.config.get(
             'TWITTER_CARD', {})
+        self.GLOBAL_CONTEXT['hide_sourcelink'] = self.config.get(
+            'HIDE_SOURCELINK')
+        self.GLOBAL_CONTEXT['extra_head_data'] = self.config.get('EXTRA_HEAD_DATA')
 
         self.GLOBAL_CONTEXT.update(self.config.get('GLOBAL_CONTEXT', {}))
 
         # check if custom css exist and is not empty
-        for files_path in list(self.config['FILES_FOLDERS'].keys()):
-            custom_css_path = os.path.join(files_path, 'assets/css/custom.css')
-            if self.file_exists(custom_css_path, not_empty=True):
-                self.GLOBAL_CONTEXT['has_custom_css'] = True
-                break
+        custom_css_path = utils.get_asset_path(
+            'assets/css/custom.css',
+            self.THEMES,
+            self.config['FILES_FOLDERS']
+        )
+        if custom_css_path and self.file_exists(custom_css_path, not_empty=True):
+            self.GLOBAL_CONTEXT['has_custom_css'] = True
         else:
             self.GLOBAL_CONTEXT['has_custom_css'] = False
 
@@ -268,19 +342,26 @@ class Nikola(object):
                              "plugin\n".format(template_sys_name))
             sys.exit(1)
         self.template_system = pi.plugin_object
-        lookup_dirs = [os.path.join(utils.get_theme_path(name), "templates")
-                       for name in self.THEMES]
+        lookup_dirs = ['templates'] + [os.path.join(utils.get_theme_path(name), "templates")
+                                       for name in self.THEMES]
         self.template_system.set_directories(lookup_dirs,
                                              self.config['CACHE_FOLDER'])
 
+        # Check consistency of USE_CDN and the current THEME (Issue #386)
+        if self.config['USE_CDN']:
+            bootstrap_path = utils.get_asset_path(os.path.join(
+                'assets', 'css', 'bootstrap.min.css'), self.THEMES)
+            if bootstrap_path.split(os.sep)[-4] != 'site':
+                warnings.warn('The USE_CDN option may be incompatible with your theme, because it uses a hosted version of bootstrap.')
+
         # Load compiler plugins
         self.compilers = {}
         self.inverse_compilers = {}
 
-        for pluginInfo in self.plugin_manager.getPluginsOfCategory(
+        for plugin_info in self.plugin_manager.getPluginsOfCategory(
                 "PageCompiler"):
-            self.compilers[pluginInfo.name] = \
-                pluginInfo.plugin_object.compile_html
+            self.compilers[plugin_info.name] = \
+                plugin_info.plugin_object
 
     def get_compiler(self, source_name):
         """Get the correct compiler for a post from `conf.post_compilers`
@@ -324,11 +405,9 @@ class Nikola(object):
         data = self.template_system.render_template(
             template_name, None, local_context)
 
-        assert isinstance(output_name, bytes)
         assert output_name.startswith(
-            self.config["OUTPUT_FOLDER"].encode('utf8'))
-        url_part = output_name.decode('utf8')[len(self.config["OUTPUT_FOLDER"])
-                                              + 1:]
+            self.config["OUTPUT_FOLDER"])
+        url_part = output_name[len(self.config["OUTPUT_FOLDER"]) + 1:]
 
         # Treat our site as if output/ is "/" and then make all URLs relative,
         # making the site "relocatable"
@@ -392,7 +471,20 @@ class Nikola(object):
         with open(output_name, "wb+") as post_file:
             post_file.write(data)
 
-    def path(self, kind, name, lang, is_link=False):
+    def current_lang(self):  # FIXME: this is duplicated, turn into a mixin
+        """Return the currently set locale, if it's one of the
+        available translations, or default_lang."""
+        lang = utils.LocaleBorg().current_lang
+        if lang:
+            if lang in self.translations:
+                return lang
+            lang = lang.split('_')[0]
+            if lang in self.translations:
+                return lang
+        # whatever
+        return self.default_lang
+
+    def path(self, kind, name, lang=None, is_link=False):
         """Build the path to a certain kind of page.
 
         kind is one of:
@@ -417,11 +509,15 @@ class Nikola(object):
         (ex: "archive\\index.html")
         """
 
+        if lang is None:
+            lang = self.current_lang()
+
         path = []
 
         if kind == "tag_index":
             path = [_f for _f in [self.config['TRANSLATIONS'][lang],
-                                  self.config['TAG_PATH'], 'index.html'] if _f]
+                                  self.config['TAG_PATH'],
+                                  self.config['INDEX_FILE']] if _f]
         elif kind == "tag":
             if self.config['SLUG_TAG_PATH']:
                 name = utils.slugify(name)
@@ -441,11 +537,13 @@ class Nikola(object):
                                       'index-{0}.html'.format(name)] if _f]
             else:
                 path = [_f for _f in [self.config['TRANSLATIONS'][lang],
-                                      self.config['INDEX_PATH'], 'index.html']
+                                      self.config['INDEX_PATH'],
+                                      self.config['INDEX_FILE']]
                         if _f]
         elif kind == "post_path":
             path = [_f for _f in [self.config['TRANSLATIONS'][lang],
-                                  os.path.dirname(name), "index.html"] if _f]
+                                  os.path.dirname(name),
+                                  self.config['INDEX_FILE']] if _f]
         elif kind == "rss":
             path = [_f for _f in [self.config['TRANSLATIONS'][lang],
                                   self.config['RSS_PATH'], 'rss.xml'] if _f]
@@ -453,19 +551,25 @@ class Nikola(object):
             if name:
                 path = [_f for _f in [self.config['TRANSLATIONS'][lang],
                                       self.config['ARCHIVE_PATH'], name,
-                                      'index.html'] if _f]
+                                      self.config['INDEX_FILE']] if _f]
             else:
                 path = [_f for _f in [self.config['TRANSLATIONS'][lang],
                                       self.config['ARCHIVE_PATH'],
                                       self.config['ARCHIVE_FILENAME']] if _f]
         elif kind == "gallery":
             path = [_f for _f in [self.config['GALLERY_PATH'], name,
-                                  'index.html'] if _f]
+                                  self.config['INDEX_FILE']] if _f]
         elif kind == "listing":
             path = [_f for _f in [self.config['LISTINGS_FOLDER'], name +
                                   '.html'] if _f]
         if is_link:
-            return '/' + ('/'.join(path))
+            link = '/' + ('/'.join(path))
+            index_len = len(self.config['INDEX_FILE'])
+            if self.config['STRIP_INDEXES'] and \
+                    link[-(1 + index_len):] == '/' + self.config['INDEX_FILE']:
+                return link[:-index_len]
+            else:
+                return link
         else:
             return os.path.join(*path)
 
@@ -510,12 +614,7 @@ class Nikola(object):
             exists = os.stat(path).st_size > 0
         return exists
 
-    def gen_tasks(self):
-
-        def create_gzipped_copy(in_path, out_path):
-            with gzip.GzipFile(out_path, 'wb+') as outf:
-                with open(in_path, 'rb') as inf:
-                    outf.write(inf.read())
+    def gen_tasks(self, name, plugin_category):
 
         def flatten(task):
             if isinstance(task, dict):
@@ -525,55 +624,21 @@ class Nikola(object):
                     for ft in flatten(t):
                         yield ft
 
-        def add_gzipped_copies(task):
-            if not self.config['GZIP_FILES']:
-                return None
-            gzip_task = {
-                'file_dep': [],
-                'targets': [],
-                'actions': [],
-                'basename': 'gzip',
-                'name': task.get('name', 'unknown'),
-                'clean': True,
-            }
-            targets = task.get('targets', [])
-            flag = False
-            for target in targets:
-                ext = os.path.splitext(target)[1]
-                if (ext.lower() in self.config['GZIP_EXTENSIONS'] and
-                        target.startswith(self.config['OUTPUT_FOLDER'])):
-                    flag = True
-                    gzipped = target + '.gz'
-                    gzip_task['file_dep'].append(target)
-                    gzip_task['targets'].append(gzipped)
-                    gzip_task['actions'].append((create_gzipped_copy, (target, gzipped)))
-            if not flag:
-                return None
-            return gzip_task
-
-        if self.config['GZIP_FILES']:
-            task_dep = ['gzip']
-        else:
-            task_dep = []
-        for pluginInfo in self.plugin_manager.getPluginsOfCategory("Task"):
+        task_dep = []
+        for pluginInfo in self.plugin_manager.getPluginsOfCategory(plugin_category):
             for task in flatten(pluginInfo.plugin_object.gen_tasks()):
-                gztask = add_gzipped_copies(task)
-                if gztask:
-                    yield gztask
-                yield task
-            if pluginInfo.plugin_object.is_default:
-                task_dep.append(pluginInfo.plugin_object.name)
-
-        for pluginInfo in self.plugin_manager.getPluginsOfCategory("LateTask"):
-            for task in pluginInfo.plugin_object.gen_tasks():
-                gztask = add_gzipped_copies(task)
-                if gztask:
-                    yield gztask
                 yield task
+                for multi in self.plugin_manager.getPluginsOfCategory("TaskMultiplier"):
+                    flag = False
+                    for task in multi.plugin_object.process(task, name):
+                        flag = True
+                        yield task
+                    if flag:
+                        task_dep.append('{0}_{1}'.format(name, multi.plugin_object.name))
             if pluginInfo.plugin_object.is_default:
                 task_dep.append(pluginInfo.plugin_object.name)
         yield {
-            'name': b'all',
+            'name': name,
             'actions': None,
             'clean': True,
             'task_dep': task_dep
@@ -588,6 +653,7 @@ class Nikola(object):
         tzinfo = None
         if self.config['TIMEZONE'] is not None:
             tzinfo = pytz.timezone(self.config['TIMEZONE'])
+        current_time = utils.current_time(tzinfo)
         targets = set([])
         for wildcard, destination, template_name, use_in_feeds in \
                 self.config['post_pages']:
@@ -597,7 +663,18 @@ class Nikola(object):
                 dir_glob = os.path.join(dirpath, os.path.basename(wildcard))
                 dest_dir = os.path.normpath(os.path.join(destination,
                                             os.path.relpath(dirpath, dirname)))
-                for base_path in glob.glob(dir_glob):
+                full_list = glob.glob(dir_glob)
+                # Now let's look for things that are not in default_lang
+                for lang in self.config['TRANSLATIONS'].keys():
+                    lang_glob = dir_glob + "." + lang
+                    translated_list = glob.glob(lang_glob)
+                    for fname in translated_list:
+                        orig_name = os.path.splitext(fname)[0]
+                        if orig_name in full_list:
+                            continue
+                        full_list.append(orig_name)
+
+                for base_path in full_list:
                     post = Post(
                         base_path,
                         self.config['CACHE_FOLDER'],
@@ -609,26 +686,38 @@ class Nikola(object):
                         self.MESSAGES,
                         template_name,
                         self.config['FILE_METADATA_REGEXP'],
+                        self.config['STRIP_INDEXES'],
+                        self.config['INDEX_FILE'],
                         tzinfo,
+                        current_time,
+                        self.config['HIDE_UNTRANSLATED_POSTS'],
+                        self.config['PRETTY_URLS'],
                     )
                     for lang, langpath in list(
                             self.config['TRANSLATIONS'].items()):
                         dest = (destination, langpath, dir_glob,
-                                post.pagenames[lang])
+                                post.meta[lang]['slug'])
                         if dest in targets:
                             raise Exception('Duplicated output path {0!r} '
                                             'in post {1!r}'.format(
-                                                post.pagenames[lang],
+                                                post.meta[lang]['slug'],
                                                 base_path))
                         targets.add(dest)
                     self.global_data[post.post_name] = post
                     if post.use_in_feeds:
                         self.posts_per_year[
                             str(post.date.year)].append(post.post_name)
-                        for tag in post.tags:
+                        self.posts_per_month[
+                            '{0}/{1:02d}'.format(post.date.year, post.date.month)].append(post.post_name)
+                        for tag in post.alltags:
                             self.posts_per_tag[tag].append(post.post_name)
                     else:
                         self.pages.append(post)
+                    if self.config['OLD_THEME_SUPPORT']:
+                        post._add_old_metadata()
+                    self.post_per_file[post.destination_path(lang=lang)] = post
+                    self.post_per_file[post.destination_path(lang=lang, extension=post.source_ext())] = post
+
         for name, post in list(self.global_data.items()):
             self.timeline.append(post)
         self.timeline.sort(key=lambda p: p.date)
@@ -656,8 +745,9 @@ class Nikola(object):
             context['enable_comments'] = True
         else:
             context['enable_comments'] = self.config['COMMENTS_IN_STORIES']
+        extension = self.get_compiler(post.source_path).extension()
         output_name = os.path.join(self.config['OUTPUT_FOLDER'],
-                                   post.destination_path(lang)).encode('utf8')
+                                   post.destination_path(lang, extension))
         deps_dict = copy(context)
         deps_dict.pop('post')
         if post.prev_post:
@@ -668,9 +758,11 @@ class Nikola(object):
         deps_dict['TRANSLATIONS'] = self.config['TRANSLATIONS']
         deps_dict['global'] = self.GLOBAL_CONTEXT
         deps_dict['comments'] = context['enable_comments']
+        if post:
+            deps_dict['post_translations'] = post.translated_to
 
         task = {
-            'name': output_name,
+            'name': os.path.normpath(output_name),
             'file_dep': deps,
             'targets': [output_name],
             'actions': [(self.render_template, [post.template_name,
@@ -685,9 +777,6 @@ class Nikola(object):
                                    template_name, filters, extra_context):
         """Renders pages with lists of posts."""
 
-        # This is a name on disk, has to be bytes
-        assert isinstance(output_name, bytes)
-
         deps = self.template_system.template_deps(template_name)
         for post in posts:
             deps += post.deps(lang)
@@ -700,11 +789,11 @@ class Nikola(object):
         context["nextlink"] = None
         context.update(extra_context)
         deps_context = copy(context)
-        deps_context["posts"] = [(p.titles[lang], p.permalink(lang)) for p in
+        deps_context["posts"] = [(p.meta[lang]['title'], p.permalink(lang)) for p in
                                  posts]
         deps_context["global"] = self.GLOBAL_CONTEXT
         task = {
-            'name': output_name,
+            'name': os.path.normpath(output_name),
             'targets': [output_name],
             'file_dep': deps,
             'actions': [(self.render_template, [template_name, output_name,
@@ -714,3 +803,14 @@ class Nikola(object):
         }
 
         return utils.apply_filters(task, filters)
+
+
+def s_l(lang):
+    """A set_locale that uses utf8 encoding and returns ''."""
+    utils.LocaleBorg().current_lang = lang
+    try:
+        locale.setlocale(locale.LC_ALL, (lang, "utf8"))
+    except Exception:
+        print("WARNING: could not set locale to {0}."
+              "This may cause some i18n features not to work.".format(lang))
+    return ''
