@@ -23,8 +23,6 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 from __future__ import unicode_literals, print_function
-import codecs
-import csv
 import datetime
 import os
 import time
@@ -38,30 +36,20 @@ try:
     import feedparser
 except ImportError:
     feedparser = None  # NOQA
-from lxml import html
-from mako.template import Template
 
 from nikola.plugin_categories import Command
 from nikola import utils
-
-links = {}
+from nikola.plugins.basic_import import ImportMixin
 
 
-class CommandImportBlogger(Command):
+class CommandImportBlogger(Command, ImportMixin):
     """Import a blogger dump."""
 
     name = "import_blogger"
     needs_config = False
     doc_usage = "[options] blogger_export_file"
     doc_purpose = "Import a blogger dump."
-    cmd_options = [
-        {
-            'name': 'output_folder',
-            'long': 'output-folder',
-            'short': 'o',
-            'default': 'new_site',
-            'help': 'Location to write imported content.'
-        },
+    cmd_options = ImportMixin.cmd_options + [
         {
             'name': 'exclude_drafts',
             'long': 'no-drafts',
@@ -73,8 +61,7 @@ class CommandImportBlogger(Command):
     ]
 
     def _execute(self, options, args):
-        """Import a Wordpress blog from an export file into a Nikola site."""
-
+        """Import a Blogger blog from an export file into a Nikola site."""
         # Parse the data
         if feedparser is None:
             print('To use the import_blogger command,'
@@ -110,33 +97,6 @@ class CommandImportBlogger(Command):
             raise Exception("Missing file: %s" % filename)
         return feedparser.parse(filename)
 
-    @staticmethod
-    def configure_redirections(url_map):
-        redirections = []
-        for k, v in url_map.items():
-            # remove the initial "/" because src is a relative file path
-            src = (urlparse(k).path + 'index.html')[1:]
-            dst = (urlparse(v).path)
-            if src == 'index.html':
-                print("Can't do a redirect for: {0!r}".format(k))
-            else:
-                redirections.append((src, dst))
-
-        return redirections
-
-    def generate_base_site(self):
-        if not os.path.exists(self.output_folder):
-            os.system('nikola init --empty ' + self.output_folder)
-        else:
-            self.import_into_existing_site = True
-            print('The folder {0} already exists - assuming that this is a '
-                  'already existing nikola site.'.format(self.output_folder))
-
-        conf_template = Template(filename=os.path.join(
-            os.path.dirname(utils.__file__), 'conf.py.in'))
-
-        return conf_template
-
     @staticmethod
     def populate_context(channel):
         context = {}
@@ -161,25 +121,6 @@ class CommandImportBlogger(Command):
 
         return context
 
-    @classmethod
-    def transform_content(cls, content):
-        # No transformations yet
-        return content
-
-    @classmethod
-    def write_content(cls, filename, content):
-        doc = html.document_fromstring(content)
-        doc.rewrite_links(replacer)
-
-        with open(filename, "wb+") as fd:
-            fd.write(html.tostring(doc, encoding='utf8'))
-
-    @staticmethod
-    def write_metadata(filename, title, slug, post_date, description, tags):
-        with codecs.open(filename, "w+", "utf8") as fd:
-            fd.write('\n'.join((title, slug, post_date, ','.join(tags), '',
-                                description)))
-
     def import_item(self, item, out_folder=None):
         """Takes an item from the feed and creates a post file."""
         if out_folder is None:
@@ -272,30 +213,3 @@ class CommandImportBlogger(Command):
     def import_posts(self, channel):
         for item in channel.entries:
             self.process_item(item)
-
-    @staticmethod
-    def write_urlmap_csv(output_file, url_map):
-        with codecs.open(output_file, 'w+', 'utf8') as fd:
-            csv_writer = csv.writer(fd)
-            for item in url_map.items():
-                csv_writer.writerow(item)
-
-    def get_configuration_output_path(self):
-        if not self.import_into_existing_site:
-            filename = 'conf.py'
-        else:
-            filename = 'conf.py.wordpress_import-{0}'.format(
-                datetime.datetime.now().strftime('%Y%m%d_%H%M%s'))
-        config_output_path = os.path.join(self.output_folder, filename)
-        print('Configuration will be written to: ' + config_output_path)
-
-        return config_output_path
-
-    @staticmethod
-    def write_configuration(filename, rendered_template):
-        with codecs.open(filename, 'w+', 'utf8') as fd:
-            fd.write(rendered_template)
-
-
-def replacer(dst):
-    return links.get(dst, dst)
