@@ -23,19 +23,15 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 from __future__ import unicode_literals, print_function
-import codecs
-import csv
-import datetime
 import os
 import re
+from lxml import etree
 
 try:
     from urlparse import urlparse
+    from urllib import unquote
 except ImportError:
-    from urllib.parse import urlparse  # NOQA
-
-from lxml import etree, html
-from mako.template import Template
+    from urllib.parse import urlparse, unquote  # NOQA
 
 try:
     import requests
@@ -44,25 +40,17 @@ except ImportError:
 
 from nikola.plugin_categories import Command
 from nikola import utils
-
-links = {}
+from nikola.plugins.basic_import import ImportMixin, links
 
 
-class CommandImportWordpress(Command):
+class CommandImportWordpress(Command, ImportMixin):
     """Import a wordpress dump."""
 
     name = "import_wordpress"
     needs_config = False
     doc_usage = "[options] wordpress_export_file"
     doc_purpose = "Import a wordpress dump."
-    cmd_options = [
-        {
-            'name': 'output_folder',
-            'long': 'output-folder',
-            'short': 'o',
-            'default': 'new_site',
-            'help': 'Location to write imported content.'
-        },
+    cmd_options = ImportMixin.cmd_options + [
         {
             'name': 'exclude_drafts',
             'long': 'no-drafts',
@@ -90,7 +78,6 @@ class CommandImportWordpress(Command):
     def _execute(self, options={}, args=[]):
         """Import a Wordpress blog from an export file into a Nikola site."""
         # Parse the data
-        print(options, args)
         if requests is None:
             print('To use the import_wordpress command,'
                   ' you have to install the "requests" package.')
@@ -100,10 +87,16 @@ class CommandImportWordpress(Command):
             print(self.help())
             return
 
-        options['filename'] = args[0]
+        options['filename'] = args.pop(0)
 
-        if len(args) > 1:
-            options['output_folder'] = args[1]
+        if args and ('output_folder' not in args or
+                     options['output_folder'] == 'new_site'):
+            options['output_folder'] = args.pop(0)
+
+        if args:
+            print('You specified additional arguments ({0}). Please consider '
+                  'putting these arguments before the filename if you '
+                  'are running into problems.'.format(args))
 
         self.wordpress_export_file = options['filename']
         self.squash_newlines = options.get('squash_newlines', False)
@@ -115,6 +108,7 @@ class CommandImportWordpress(Command):
         channel = self.get_channel_from_file(self.wordpress_export_file)
         self.context = self.populate_context(channel)
         conf_template = self.generate_base_site()
+        self.timezone = None
 
         self.import_posts(channel)
 
@@ -125,6 +119,10 @@ class CommandImportWordpress(Command):
         rendered_template = conf_template.render(**self.context)
         rendered_template = re.sub('# REDIRECTIONS = ', 'REDIRECTIONS = ',
                                    rendered_template)
+        if self.timezone:
+            rendered_template = re.sub('# TIMEZONE = \'Europe/Zurich\'',
+                                       'TIMEZONE = \'' + self.timezone + '\'',
+                                       rendered_template)
         self.write_configuration(self.get_configuration_output_path(),
                                  rendered_template)
 
@@ -167,33 +165,6 @@ class CommandImportWordpress(Command):
         channel = tree.find('channel')
         return channel
 
-    @staticmethod
-    def configure_redirections(url_map):
-        redirections = []
-        for k, v in url_map.items():
-            # remove the initial "/" because src is a relative file path
-            src = (urlparse(k).path + 'index.html')[1:]
-            dst = (urlparse(v).path)
-            if src == 'index.html':
-                print("Can't do a redirect for: {0!r}".format(k))
-            else:
-                redirections.append((src, dst))
-
-        return redirections
-
-    def generate_base_site(self):
-        if not os.path.exists(self.output_folder):
-            os.system('nikola init ' + self.output_folder)
-        else:
-            self.import_into_existing_site = True
-            print('The folder {0} already exists - assuming that this is a '
-                  'already existing nikola site.'.format(self.output_folder))
-
-        conf_template = Template(filename=os.path.join(
-            os.path.dirname(utils.__file__), 'conf.py.in'))
-
-        return conf_template
-
     @staticmethod
     def populate_context(channel):
         wordpress_namespace = channel.nsmap['wp']
@@ -204,8 +175,14 @@ class CommandImportWordpress(Command):
                                              'PUT TITLE HERE')
         context['BLOG_DESCRIPTION'] = get_text_tag(
             channel, 'description', 'PUT DESCRIPTION HERE')
-        context['SITE_URL'] = get_text_tag(channel, 'link', '#')
         context['BASE_URL'] = get_text_tag(channel, 'link', '#')
+        if not context['BASE_URL']:
+            base_site_url = channel.find('{{{0}}}author'.format(wordpress_namespace))
+            context['BASE_URL'] = get_text_tag(base_site_url,
+                                               None,
+                                               "http://foo.com")
+        context['SITE_URL'] = context['BASE_URL']
+
         author = channel.find('{{{0}}}author'.format(wordpress_namespace))
         context['BLOG_EMAIL'] = get_text_tag(
             author,
@@ -284,27 +261,6 @@ class CommandImportWordpress(Command):
         new_content = self.transform_multiple_newlines(new_content)
         return new_content
 
-    @classmethod
-    def write_content(cls, filename, content):
-        doc = html.document_fromstring(content)
-        doc.rewrite_links(replacer)
-
-        with open(filename, "wb+") as fd:
-            fd.write(html.tostring(doc, encoding='utf8'))
-
-    @staticmethod
-    def write_metadata(filename, title, slug, post_date, description, tags):
-        if not description:
-            description = ""
-
-        with codecs.open(filename, "w+", "utf8") as fd:
-            fd.write('{0}\n'.format(title))
-            fd.write('{0}\n'.format(slug))
-            fd.write('{0}\n'.format(post_date))
-            fd.write('{0}\n'.format(','.join(tags)))
-            fd.write('\n')
-            fd.write('{0}\n'.format(description))
-
     def import_item(self, item, wordpress_namespace, out_folder=None):
         """Takes an item from the feed and creates a post file."""
         if out_folder is None:
@@ -314,7 +270,14 @@ class CommandImportWordpress(Command):
         # link is something like http://foo.com/2012/09/01/hello-world/
         # So, take the path, utils.slugify it, and that's our slug
         link = get_text_tag(item, 'link', None)
-        slug = utils.slugify(urlparse(link).path)
+        path = unquote(urlparse(link).path)
+
+        # In python 2, path is a str. slug requires a unicode
+        # object. According to wikipedia, unquoted strings will
+        # usually be UTF8
+        if isinstance(path, utils.bytes_str):
+            path = path.decode('utf8')
+        slug = utils.slugify(path)
         if not slug:  # it happens if the post has no "nice" URL
             slug = get_text_tag(
                 item, '{{{0}}}post_name'.format(wordpress_namespace), None)
@@ -328,13 +291,19 @@ class CommandImportWordpress(Command):
         description = get_text_tag(item, 'description', '')
         post_date = get_text_tag(
             item, '{{{0}}}post_date'.format(wordpress_namespace), None)
+        dt = utils.to_datetime(post_date)
+        if dt.tzinfo and self.timezone is None:
+            self.timezone = utils.get_tzname(dt)
         status = get_text_tag(
             item, '{{{0}}}status'.format(wordpress_namespace), 'publish')
         content = get_text_tag(
             item, '{http://purl.org/rss/1.0/modules/content/}encoded', '')
 
         tags = []
-        if status != 'publish':
+        if status == 'trash':
+            print('Trashed post "{0}" will not be imported.'.format(title))
+            return
+        elif status != 'publish':
             tags.append('draft')
             is_draft = True
         else:
@@ -383,33 +352,6 @@ class CommandImportWordpress(Command):
         for item in channel.findall('item'):
             self.process_item(item)
 
-    @staticmethod
-    def write_urlmap_csv(output_file, url_map):
-        with codecs.open(output_file, 'w+', 'utf8') as fd:
-            csv_writer = csv.writer(fd)
-            for item in url_map.items():
-                csv_writer.writerow(item)
-
-    def get_configuration_output_path(self):
-        if not self.import_into_existing_site:
-            filename = 'conf.py'
-        else:
-            filename = 'conf.py.wordpress_import-{0}'.format(
-                datetime.datetime.now().strftime('%Y%m%d_%H%M%s'))
-        config_output_path = os.path.join(self.output_folder, filename)
-        print('Configuration will be written to:', config_output_path)
-
-        return config_output_path
-
-    @staticmethod
-    def write_configuration(filename, rendered_template):
-        with codecs.open(filename, 'w+', 'utf8') as fd:
-            fd.write(rendered_template)
-
-
-def replacer(dst):
-    return links.get(dst, dst)
-
 
 def get_text_tag(tag, name, default):
     if tag is None:
