@@ -57,13 +57,17 @@ class CommandInstallTheme(Command):
             'long': 'url',
             'type': str,
             'help': "URL for the theme repository (default: "
-                    "http://nikola.ralsina.com.ar/themes/index.json)",
-            'default': 'http://nikola.ralsina.com.ar/themes/index.json'
+                    "http://themes.nikola.ralsina.com.ar/themes.json)",
+            'default': 'http://themes.nikola.ralsina.com.ar/themes.json'
         },
     ]
 
     def _execute(self, options, args):
         """Install theme into current site."""
+        if requests is None:
+            print('This command requires the requests package be installed.')
+            return False
+
         listing = options['list']
         url = options['url']
         if args:
