@@ -23,7 +23,8 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 from docutils import nodes
-from docutils.parsers.rst import directives
+from docutils.parsers.rst import Directive, directives
+
 
 CODE = """\
 <iframe width="{width}"
@@ -32,25 +33,37 @@ src="http://www.youtube.com/embed/{yid}?rel=0&amp;hd=1&amp;wmode=transparent"
 ></iframe>"""
 
 
-def youtube(name, args, options, content, lineno,
-            contentOffset, blockText, state, stateMachine):
-    """ Restructured text extension for inserting youtube embedded videos """
-    if len(content) == 0:
-        return
-    string_vars = {
-        'yid': content[0],
-        'width': 425,
-        'height': 344,
-        'extra': ''
+class Youtube(Directive):
+    """ Restructured text extension for inserting youtube embedded videos
+
+    Usage:
+        .. youtube:: lyViVmaBQDg
+           :height: 400
+           :width: 600
+
+    """
+    has_content = True
+    required_arguments = 1
+    option_spec = {
+        "width": directives.positive_int,
+        "height": directives.positive_int,
     }
-    extra_args = content[1:]  # Because content[0] is ID
-    extra_args = [ea.strip().split("=") for ea in extra_args]  # key=value
-    extra_args = [ea for ea in extra_args if len(ea) == 2]  # drop bad lines
-    extra_args = dict(extra_args)
-    if 'width' in extra_args:
-        string_vars['width'] = extra_args.pop('width')
-    if 'height' in extra_args:
-        string_vars['height'] = extra_args.pop('height')
-    return [nodes.raw('', CODE.format(**string_vars), format='html')]
-youtube.content = True
-directives.register_directive('youtube', youtube)
+
+    def run(self):
+        self.check_content()
+        options = {
+            'yid': self.arguments[0],
+            'width': 425,
+            'height': 344,
+        }
+        options.update(self.options)
+        return [nodes.raw('', CODE.format(**options), format='html')]
+
+    def check_content(self):
+        if self.content:
+            raise self.warning("This directive does not accept content. The "
+                               "'key=value' format for options is deprecated, "
+                               "use ':key: value' instead")
+
+
+directives.register_directive('youtube', Youtube)
