@@ -52,6 +52,7 @@ class RenderTags(Task):
             self.site.config['INDEX_DISPLAY_POST_COUNT'],
             "index_teasers": self.site.config['INDEX_TEASERS'],
             "rss_teasers": self.site.config["RSS_TEASERS"],
+            "hide_untranslated_posts": self.site.config['HIDE_UNTRANSLATED_POSTS'],
         }
 
         self.site.scan_posts()
@@ -67,13 +68,17 @@ class RenderTags(Task):
             post_list.sort(key=lambda a: a.date)
             post_list.reverse()
             for lang in kw["translations"]:
-                yield self.tag_rss(tag, lang, posts, kw)
-
+                if kw["hide_untranslated_posts"]:
+                    filtered_posts = [x for x in post_list if x.is_translation_available(lang)]
+                else:
+                    filtered_posts = post_list
+                rss_post_list = [p.post_name for p in filtered_posts]
+                yield self.tag_rss(tag, lang, rss_post_list, kw)
                 # Render HTML
                 if kw['tag_pages_are_indexes']:
-                    yield self.tag_page_as_index(tag, lang, post_list, kw)
+                    yield self.tag_page_as_index(tag, lang, filtered_posts, kw)
                 else:
-                    yield self.tag_page_as_list(tag, lang, post_list, kw)
+                    yield self.tag_page_as_list(tag, lang, filtered_posts, kw)
 
         # Tag cloud json file
         tag_cloud_data = {}
@@ -98,6 +103,7 @@ class RenderTags(Task):
         task['uptodate'] = [utils.config_changed(tag_cloud_data)]
         task['targets'] = [output_name]
         task['actions'] = [(write_tag_data, [tag_cloud_data])]
+        task['clean'] = True
         yield task
 
     def list_tags_page(self, kw):
@@ -110,7 +116,7 @@ class RenderTags(Task):
         for lang in kw["translations"]:
             output_name = os.path.join(
                 kw['output_folder'], self.site.path('tag_index', None, lang))
-            output_name = output_name.encode('utf8')
+            output_name = output_name
             context = {}
             context["title"] = kw["messages"][lang]["Tags"]
             context["items"] = [(tag, self.site.link("tag", tag, lang)) for tag
@@ -157,7 +163,6 @@ class RenderTags(Task):
             context['rss_link'] = rss_link
             output_name = os.path.join(kw['output_folder'],
                                        page_name(tag, i, lang))
-            output_name = output_name.encode('utf8')
             context["title"] = kw["messages"][lang][
                 "Posts about %s"] % tag
             context["prevlink"] = None
@@ -192,7 +197,6 @@ class RenderTags(Task):
         template_name = "tag.tmpl"
         output_name = os.path.join(kw['output_folder'], self.site.path(
             "tag", tag, lang))
-        output_name = output_name.encode('utf8')
         context = {}
         context["lang"] = lang
         context["title"] = kw["messages"][lang]["Posts about %s"] % tag
@@ -217,7 +221,6 @@ class RenderTags(Task):
         #Render RSS
         output_name = os.path.join(kw['output_folder'],
                                    self.site.path("tag_rss", tag, lang))
-        output_name = output_name.encode('utf8')
         deps = []
         post_list = [self.site.global_data[post] for post in posts if
                      self.site.global_data[post].use_in_feeds]
@@ -236,4 +239,5 @@ class RenderTags(Task):
                          output_name, kw["rss_teasers"]))],
             'clean': True,
             'uptodate': [utils.config_changed(kw)],
+            'task_dep': ['render_posts'],
         }
